@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "dialog_import_csv.h"
@@ -27,6 +27,9 @@
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/cellrenderercombo.h>
 #include <glom/utils_ui.h>
+#include <gtkmm/main.h>
+#include <glibmm/convert.h>
+#include <glibmm/markup.h>
 #include <glibmm/i18n.h>
 #include <cerrno>
 #include <iostream>
