@@ -278,7 +278,7 @@ bool recreate_database_from_document(Document* document, const sigc::slot<void>&
     Document::type_vec_fields fields = document->get_table_fields(table_info->get_name());
 
     progress();
-    const bool table_creation_succeeded = create_table(table_info, fields);
+    const bool table_creation_succeeded = create_table(document->get_hosting_mode(), table_info, fields);
     progress();
     if(!table_creation_succeeded)
     {
@@ -465,7 +465,7 @@ bool add_standard_tables(Document* document)
     //Name, address, etc:
     if(!get_table_exists_in_database(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME))
     {
-      const bool test = create_table(prefs_table_info, pref_fields);
+      const bool test = create_table(document->get_hosting_mode(), prefs_table_info, pref_fields);
 
       if(test)
       {
@@ -535,7 +535,7 @@ bool add_standard_tables(Document* document)
       field_next_value->set_glom_type(Field::TYPE_TEXT);
       fields.push_back(field_next_value);
 
-      const bool test = create_table(table_info, fields);
+      const bool test = create_table(document->get_hosting_mode(), table_info, fields);
       if(!test)
       {
         std::cerr << G_STRFUNC << ": add_standard_tables(): create_table(autoincrements) failed." << std::endl;
@@ -1199,7 +1199,7 @@ bool create_table_with_default_fields(Document* document, const Glib::ustring& t
   table_info->set_name(table_name);
   table_info->set_title_original( Utils::title_from_string( table_name ) ); //Start with a title that might be appropriate.
 
-  created = create_table(table_info, fields);
+  created = create_table(document->get_hosting_mode(), table_info, fields);
 
   if(created)
   {
@@ -1213,7 +1213,7 @@ bool create_table_with_default_fields(Document* document, const Glib::ustring& t
 
   return created;
 }
-bool create_table(const sharedptr<const TableInfo>& table_info, const Document::type_vec_fields& fields_in)
+bool create_table(Document::HostingMode hosting_mode, const sharedptr<const TableInfo>& table_info, const Document::type_vec_fields& fields_in)
 {
   //std::cout << "debug: " << G_STRFUNC << ": " << table_info->get_name() << ", title=" << table_info->get_title() << std::endl;
 
@@ -1245,7 +1245,20 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
     info->set_g_type( Field::get_gda_type_for_glom_type(field->get_glom_type()) );
     field->set_field_info(info); //TODO_Performance
 
-    Glib::ustring sql_field_description = escape_sql_id(field->get_name()) + " " + field->get_sql_type();
+    Glib::ustring field_type = field->get_sql_type();
+
+    if( (hosting_mode == Document::HOSTING_MODE_MYSQL_CENTRAL) ||
+      (hosting_mode == Document::HOSTING_MODE_MYSQL_SELF) )
+    {
+      if(field_type == "varchar")
+        field_type = "varchar(255)";
+      else if(field_type == "VARBINARY")
+        field_type = "blob"; //Because VARBINARY needs us to specify a size.
+      else if(field_type == "DECIMAL")
+        field_type = "double"; //Because DECIMAL with no parameters means no decimal points.
+    }
+
+    Glib::ustring sql_field_description = escape_sql_id(field->get_name()) + " " + field_type;
 
     if(field->get_primary_key())
       sql_field_description += " NOT NULL  PRIMARY KEY";
@@ -1267,7 +1280,10 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
   {
     //TODO: Escape the table name?
     //TODO: Use GDA_SERVER_OPERATION_CREATE_TABLE instead?
-    table_creation_succeeded = query_execute_string( "CREATE TABLE " + escape_sql_id(table_info->get_name()) + " (" + sql_fields + ");" );
+    const Glib::ustring query = "CREATE TABLE " + escape_sql_id(table_info->get_name()) + " (" + sql_fields + ");";
+    //std::cout << G_STRFUNC << ": debug: CREATE TABLE query:" << std::endl;
+    //std::cout << "    " << query << std::endl;
+    table_creation_succeeded = query_execute_string(query);
     if(!table_creation_succeeded)
       std::cerr << G_STRFUNC << ": CREATE TABLE failed." << std::endl;
   }
@@ -1504,6 +1520,14 @@ static void recalculate_next_auto_increment_value(const Glib::ustring& table_nam
   {
     //Increment it:
     const Gnome::Gda::Value value_max = datamodel->get_value_at(0, 0); // A GdaNumeric.
+
+    //TODO: This happens with MySQL. Maybe it is OK, when there are no records or no values:
+    if(Glom::Conversions::value_is_empty(value_max))
+    {
+      std::cerr << G_STRFUNC << ": The MAX() value is null for query: " <<
+        Utils::sqlbuilder_get_full_query(builder) << std::endl;
+    }
+
     double num_max = Conversions::get_double_for_gda_value_numeric(value_max);
     ++num_max;
 
@@ -1571,7 +1595,7 @@ bool insert_example_data(Document* document, const Glib::ustring& table_name)
 
 
   //Get field names:
-  Document::type_vec_fields vec_fields = document->get_table_fields(table_name);
+  const Document::type_vec_fields vec_fields = document->get_table_fields(table_name);
 
   //Actually insert the data:
   //std::cout << "debug: " << G_STRFUNC << ": number of rows of data: " << vec_rows.size() << std::endl;
@@ -1589,6 +1613,8 @@ bool insert_example_data(Document* document, const Glib::ustring& table_name)
 
     //std::cout << "DEBUG: row_data size = " << row_data.size() << ", (fields size= " << vec_fields.size() << " )" << std::endl;
 
+    const Document::HostingMode hosting_mode = document->get_hosting_mode();
+
     Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
     builder->set_table(table_name);
     for(unsigned int i = 0; i < row_data.size(); ++i) //TODO_Performance: Avoid calling size() so much.
@@ -1602,6 +1628,17 @@ bool insert_example_data(Document* document, const Glib::ustring& table_name)
         break;
       }
 
+      if(field->get_glom_type() == Field::TYPE_IMAGE)
+      {
+        if((hosting_mode == Document::HOSTING_MODE_MYSQL_CENTRAL) ||
+          (hosting_mode == Document::HOSTING_MODE_MYSQL_SELF))
+        {
+          //TODO: See https://bugzilla.gnome.org/show_bug.cgi?id=691099
+          std::cerr << G_STRFUNC << ": Skipping Image field because libgda does not support it for MySQL." << std::endl;
+          break;
+        }
+      }
+
       builder->add_field_value(field->get_name(), row_data[i]);
     }
 
@@ -1609,9 +1646,16 @@ bool insert_example_data(Document* document, const Glib::ustring& table_name)
     //After this, the Parser will know how many SQL parameters there are in
     //the query, and allow us to set their values.
 
+    //std::cout << G_STRFUNC << ": debug: INSERT query: " << std::endl
+    //  << "    " << Utils::sqlbuilder_get_full_query(builder) << std::endl;
+
     insert_succeeded = query_execute(builder);
     if(!insert_succeeded)
+    {
+      std::cerr << G_STRFUNC << ": The INSERT query failed: " <<
+        Utils::sqlbuilder_get_full_query(builder) << std::endl;
       break;
+    }
   }
 
   for(Document::type_vec_fields::const_iterator iter = vec_fields.begin(); iter != vec_fields.end(); ++iter)
@@ -1948,6 +1992,10 @@ int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql
     {
       result = value.get_int(); //With the SQLite backend.
     }
+    else if(value.get_value_type() == G_TYPE_LONG) //With the MySQL backend.
+    {
+      result = (int)value.get_long(); //With the SQLite backend.
+    }
     else
     {
       std::cerr << G_STRFUNC << ": The COUNT query returned an unexpected value type: " << g_type_name(value.get_value_type()) << std::endl;
